class LastMentionService:
    def get_last_mention(self):
        """
        Get the last mention id which was processed
        :return: The last mention id
        """
        pass

    def set_last_mention(self, last_mention):
        """
        Sets a new value to the last mention id
        :param last_mention: an id of a mention
        :return: void
        """
        pass
