class MentionAction:
    def run(self, mention):
        """
        Gets a mention (Tweepy Status object) and process it.
        :param mention:
        :return: void
        """
        pass

    def setup(self):
        """
        Sets up the environment if there is  need to.
        :return: void
        """
        pass
